@@ -409,7 +409,7 @@ class ButtonManager(AbstractWidgetManager, ABC):
             try:
                 self._check_kwargs(kwargs)
             except ValueError:
-                if self._verbose:
+                if self._menu._verbose:
                     warn('button cannot accept kwargs. If you want to use kwargs '
                          'options set accept_kwargs=True')
                 raise
