@@ -56,8 +56,11 @@ S_FINGER_FACTOR = 0.25, 0.25
 
 # Types
 FrameTitleBackgroundColorType = Optional[Union[ColorInputType, ColorInputGradientType, BaseImage]]
-FrameTitleButtonType = Literal[FRAME_TITLE_BUTTON_CLOSE, FRAME_TITLE_BUTTON_MAXIMIZE,
-                               FRAME_TITLE_BUTTON_MINIMIZE]
+FrameTitleButtonType = Literal[
+    FRAME_TITLE_BUTTON_CLOSE,
+    FRAME_TITLE_BUTTON_MAXIMIZE,
+    FRAME_TITLE_BUTTON_MINIMIZE
+]
 
 
 # noinspection PyMissingOrEmptyDocstring,PyProtectedMember
@@ -119,7 +122,6 @@ class Frame(Widget):
     first_index: int  # First selectable widget index
     horizontal: bool
     last_index: int  # Last selectable widget index
-    selected_widget_draw: Tuple[Optional['Widget'], Optional['pygame.Surface']]  # Stores selected widget
 
     def __init__(
             self,
@@ -168,7 +170,6 @@ class Frame(Widget):
         self.is_scrollable = False
         self.is_selectable = False
         self.last_index = -1
-        self.selected_widget_draw = (None, None)
 
     def set_title(
             self,
@@ -308,9 +309,7 @@ class Frame(Widget):
                 area_color.draw(title_bg, area=title_bg.get_rect())
             elif area_color is not None:
                 title_bg.fill(area_color, rect=title_bg.get_rect())
-        self._frame_title.get_decorator().add_surface(-title_bg.get_width() / 2,
-                                                      -title_bg.get_height() / 2 + 1,
-                                                      title_bg)
+        self._frame_title.get_decorator().add_surface(-title_bg.get_width() / 2, -title_bg.get_height() / 2 + 1, title_bg)
 
         # Set background
         is_color = True
@@ -750,7 +749,8 @@ class Frame(Widget):
 
         # If it has title
         if self._has_title:
-            warn(f'previous {self.get_class_id()} title has been removed')
+            if self._verbose:
+                warn(f'previous {self.get_class_id()} title has been removed')
             self.remove_title()
 
         return self
@@ -848,8 +848,7 @@ class Frame(Widget):
                 w._set_position_relative_to_frame()
         super(Frame, self).set_position(x, y)
         if self.is_scrollable:
-            self._frame_scrollarea.set_position(self._rect.x,
-                                                self._rect.y + self._title_height())
+            self._frame_scrollarea.set_position(self._rect.x, self._rect.y + self._title_height())
         return self
 
     def draw(self, surface: 'pygame.Surface') -> 'Frame':
@@ -868,6 +867,8 @@ class Frame(Widget):
                 if widget.is_selected():
                     selected_widget = widget
                 widget.draw(surface)
+            if selected_widget is not None:
+                selected_widget.draw_after_if_selected(surface)
             self._draw_border(surface)
             self._decorator.draw_post(surface)
 
@@ -884,6 +885,8 @@ class Frame(Widget):
                 if widget.is_selected():
                     selected_widget = widget
                 widget.draw(self._surface)
+            if selected_widget is not None:
+                selected_widget.draw_after_if_selected(self._surface)
             self._frame_scrollarea.draw(surface)
             self._draw_border(surface)
 
@@ -893,9 +896,6 @@ class Frame(Widget):
 
         self.apply_draw_callbacks()
 
-        # Stores selected widget
-        self.selected_widget_draw = selected_widget, self.last_surface
-
         return self
 
     def _get_ht(self, widget: 'Widget', a: str) -> int:
@@ -960,13 +960,11 @@ class Frame(Widget):
                 continue
             elif align == ALIGN_LEFT:
                 x_left += w.get_margin()[0]
-                self._pos[w.get_id()] = (x_left,
-                                         self._get_vt(w, v_pos) + w.get_margin()[1])
+                self._pos[w.get_id()] = (x_left, self._get_vt(w, v_pos) + w.get_margin()[1])
                 x_left += w.get_width()
             elif align == ALIGN_RIGHT:
                 x_right -= (w.get_width() + w.get_margin()[0])
-                self._pos[w.get_id()] = (self._width + x_right,
-                                         self._get_vt(w, v_pos) + w.get_margin()[1])
+                self._pos[w.get_id()] = (self._width + x_right, self._get_vt(w, v_pos) + w.get_margin()[1])
             dw = x_left - x_right
             if dw > self._width and not self._relax:
                 raise _FrameSizeException(
@@ -989,8 +987,7 @@ class Frame(Widget):
                 continue
             if align == ALIGN_CENTER:
                 x_center += w.get_margin()[0]
-                self._pos[w.get_id()] = (x_center,
-                                         self._get_vt(w, v_pos) + w.get_margin()[1])
+                self._pos[w.get_id()] = (x_center, self._get_vt(w, v_pos) + w.get_margin()[1])
                 x_center += w.get_width()
 
     def _update_position_vertical(self) -> None:
@@ -1013,8 +1010,7 @@ class Frame(Widget):
                 y_top += w.get_height()
             elif v_pos == POSITION_SOUTH:
                 y_bottom -= (w.get_height() + w.get_margin()[1])
-                self._pos[w.get_id()] = (self._get_ht(w, align) + w.get_margin()[0],
-                                         self._height + y_bottom)
+                self._pos[w.get_id()] = (self._get_ht(w, align) + w.get_margin()[0], self._height + y_bottom)
             dh = y_top - y_bottom
             if dh > self._height and not self._relax:
                 raise _FrameSizeException(
@@ -1038,8 +1034,7 @@ class Frame(Widget):
                 continue
             if v_pos == POSITION_CENTER:
                 y_center += w.get_margin()[1]
-                self._pos[w.get_id()] = (self._get_ht(w, align) + w.get_margin()[0],
-                                         y_center)
+                self._pos[w.get_id()] = (self._get_ht(w, align) + w.get_margin()[0], y_center)
                 y_center += w.get_height()
 
     def update_position(self) -> 'Frame':
@@ -1528,12 +1523,13 @@ class Frame(Widget):
             f'{widget.get_class_id()} must be configured before packing'
 
         if widget.get_margin() != (0, 0) and self._pack_margin_warning:
-            warn(
-                f'{widget.get_class_id()} margin should be (0, 0) if packed, but'
-                f' received {widget.get_margin()}; {self.get_class_id()}.pack() '
-                f'does not consider previous widget margin. Set '
-                f'frame._pack_margin_warning=False to hide this warning'
-            )
+            if self._verbose:
+                warn(
+                    f'{widget.get_class_id()} margin should be (0, 0) if packed, but'
+                    f' received {widget.get_margin()}; {self.get_class_id()}.pack() '
+                    f'does not consider previous widget margin. Set '
+                    f'frame._pack_margin_warning=False to hide this warning'
+                )
 
         if isinstance(widget, Frame):
             widget.update_indices()
@@ -1579,8 +1575,7 @@ class Frame(Widget):
             self._menu.move_widget_index(widget, self, render=False)
             if isinstance(widget, Frame):
                 reverse = menu_widgets.index(widget) == len(menu_widgets) - 1
-                widgs = widget.get_widgets(unpack_subframes_include_frame=True,
-                                           reverse=reverse)
+                widgs = widget.get_widgets(unpack_subframes_include_frame=True, reverse=reverse)
 
                 first_moved_widget = None
                 last_moved_widget = None
@@ -1875,27 +1870,17 @@ class FrameManager(AbstractWidgetManager, ABC):
             max_height=kwargs.pop('max_height', height) - pad_v,
             max_width=kwargs.pop('max_width', width) - pad_h,
             scrollarea_color=kwargs.pop('scrollarea_color', None),
-            scrollbar_color=kwargs.pop('scrollbar_color',
-                                       self._theme.scrollbar_color),
-            scrollbar_cursor=kwargs.pop('scrollbar_cursor',
-                                        self._theme.scrollbar_cursor),
-            scrollbar_shadow=kwargs.pop('scrollbar_shadow',
-                                        self._theme.scrollbar_shadow),
-            scrollbar_shadow_color=kwargs.pop('scrollbar_shadow_color',
-                                              self._theme.scrollbar_shadow_color),
-            scrollbar_shadow_offset=kwargs.pop('scrollbar_shadow_offset',
-                                               self._theme.scrollbar_shadow_offset),
-            scrollbar_shadow_position=kwargs.pop('scrollbar_shadow_position',
-                                                 self._theme.scrollbar_shadow_position),
-            scrollbar_slider_color=kwargs.pop('scrollbar_slider_color',
-                                              self._theme.scrollbar_slider_color),
-            scrollbar_slider_hover_color=kwargs.pop('scrollbar_slider_hover_color',
-                                                    self._theme.scrollbar_slider_hover_color),
-            scrollbar_slider_pad=kwargs.pop('scrollbar_slider_pad',
-                                            self._theme.scrollbar_slider_pad),
+            scrollbar_color=kwargs.pop('scrollbar_color', self._theme.scrollbar_color),
+            scrollbar_cursor=kwargs.pop('scrollbar_cursor', self._theme.scrollbar_cursor),
+            scrollbar_shadow=kwargs.pop('scrollbar_shadow', self._theme.scrollbar_shadow),
+            scrollbar_shadow_color=kwargs.pop('scrollbar_shadow_color', self._theme.scrollbar_shadow_color),
+            scrollbar_shadow_offset=kwargs.pop('scrollbar_shadow_offset', self._theme.scrollbar_shadow_offset),
+            scrollbar_shadow_position=kwargs.pop('scrollbar_shadow_position', self._theme.scrollbar_shadow_position),
+            scrollbar_slider_color=kwargs.pop('scrollbar_slider_color', self._theme.scrollbar_slider_color),
+            scrollbar_slider_hover_color=kwargs.pop('scrollbar_slider_hover_color', self._theme.scrollbar_slider_hover_color),
+            scrollbar_slider_pad=kwargs.pop('scrollbar_slider_pad', self._theme.scrollbar_slider_pad),
             scrollbar_thick=kwargs.pop('scrollbar_thick', self._theme.scrollbar_thick),
-            scrollbars=get_scrollbars_from_position(
-                kwargs.pop('scrollbars', self._theme.scrollarea_position))
+            scrollbars=get_scrollbars_from_position(kwargs.pop('scrollbars', self._theme.scrollarea_position))
         )
 
         self._append_widget(widget)
