@@ -93,8 +93,9 @@ class RangeSlider(Widget):
     :param range_text_value_tick_hfactor: Height factor of the range text value tick (factor of the range title height)
     :param range_text_value_tick_number: Number of range value text, the values are placed uniformly distributed
     :param range_text_value_tick_thick: Thickness of the range text value tick in px
-    :param repeat_keys_initial_ms: Time in ms before keys are repeated when held in ms
-    :param repeat_keys_interval_ms: Interval between key press repetition when held in ms
+    :param repeat_keys: Enable key repeat
+    :param repeat_keys_initial_ms: Time in milliseconds before keys are repeated when held in milliseconds
+    :param repeat_keys_interval_ms: Interval between key press repetition when held in milliseconds
     :param slider_color: Slider color
     :param slider_height_factor: Height of the slider (factor of the range title height)
     :param slider_sel_highlight_color: Color of the selected slider highlight box effect
@@ -120,6 +121,7 @@ class RangeSlider(Widget):
     _font_slider_value: Optional['pygame.font.Font']
     _increment: NumberType
     _increment_shift_factor: float
+    _keyrepeat: bool
     _keyrepeat_counters: Dict[int, int]
     _keyrepeat_initial_interval_ms: NumberType
     _keyrepeat_interval_ms: NumberType
@@ -218,6 +220,7 @@ class RangeSlider(Widget):
             range_text_value_tick_hfactor: NumberType = 0.35,
             range_text_value_tick_number: int = 2,
             range_text_value_tick_thick: int = 1,
+            repeat_keys: bool = True,
             repeat_keys_initial_ms: NumberType = 400,
             repeat_keys_interval_ms: NumberType = 50,
             slider_color: ColorInputType = (120, 120, 120),
@@ -379,6 +382,15 @@ class RangeSlider(Widget):
             'value_format must be a function that accepts only 1 argument ' \
             '(value) and must return a string'
 
+        # Check keyrepeat
+        assert isinstance(repeat_keys, bool)
+        assert isinstance(repeat_keys_initial_ms, NumberInstance)
+        assert isinstance(repeat_keys_interval_ms, NumberInstance)
+        assert repeat_keys_initial_ms > 0, \
+            'repeat keys initial ms cannot be lower or equal than zero'
+        assert repeat_keys_interval_ms > 0, \
+            'repeat keys interval ms cannot be lower or equal than zero'
+
         # Single value
         single = isinstance(default_value, NumberInstance)
 
@@ -393,6 +405,7 @@ class RangeSlider(Widget):
         self._default_value = tuple(default_value)
         self._increment = increment
         self._increment_shift_factor = 0.5
+        self._keyrepeat = repeat_keys
         self._keyrepeat_counters = {}  # {event.key: (counter_int, event.unicode)} (look for "***")
         self._keyrepeat_initial_interval_ms = repeat_keys_initial_ms
         self._keyrepeat_interval_ms = repeat_keys_interval_ms
@@ -1076,14 +1089,15 @@ class RangeSlider(Widget):
                     if self._update_value(delta):
                         updated = True
 
-        # Update key counters:
-        for key in self._keyrepeat_counters:
-            self._keyrepeat_counters[key] += time_clock  # Update clock
+        # Update key counters
+        if self._keyrepeat:
+            for key in self._keyrepeat_counters:
+                self._keyrepeat_counters[key] += time_clock  # Update clock
 
-            # Generate new key events if enough time has passed:
-            if self._keyrepeat_counters[key] >= self._keyrepeat_initial_interval_ms:
-                self._keyrepeat_counters[key] = self._keyrepeat_initial_interval_ms - self._keyrepeat_interval_ms
-                self._add_event(pygame.event.Event(pygame.KEYDOWN, key=key))
+                # Generate new key events if enough time has passed:
+                if self._keyrepeat_counters[key] >= self._keyrepeat_initial_interval_ms:
+                    self._keyrepeat_counters[key] = self._keyrepeat_initial_interval_ms - self._keyrepeat_interval_ms
+                    self._add_event(pygame.event.Event(pygame.KEYDOWN, key=key))
 
         return updated
 
@@ -1173,8 +1187,9 @@ class RangeSliderManager(AbstractWidgetManager, ABC):
             - ``range_text_value_tick_thick``   (int) - Thickness of the range text value tick in px
             - ``readonly_color``                (tuple, list, str, int, :py:class:`pygame.Color`) – Color of the widget if readonly mode
             - ``readonly_selected_color``       (tuple, list, str, int, :py:class:`pygame.Color`) – Color of the widget if readonly mode and is selected
-            - ``repeat_keys_initial_ms``        (int) - Time in ms before keys are repeated when held in ms. ``400`` by default
-            - ``repeat_keys_interval_ms``       (int) - Interval between key press repetition when held in ms. ``50`` by default
+            - ``repeat_keys``                   (bool) - Enable key repeat. ``True`` by default
+            - ``repeat_keys_initial_ms``        (int) - Time in milliseconds before keys are repeated when held in milliseconds. ``400`` by default
+            - ``repeat_keys_interval_ms``       (int) - Interval between key press repetition when held in milliseconds. ``50`` by default
             - ``selection_color``               (tuple, list, str, int, :py:class:`pygame.Color`) – Color of the selected widget; only affects the font color
             - ``selection_effect``              (:py:class:`pygame_menu.widgets.core.Selection`) – Widget selection effect
             - ``shadow_color``                  (tuple, list, str, int, :py:class:`pygame.Color`) – Color of the widget shadow
