@@ -297,8 +297,7 @@ class Table(Frame):
             row_background_color = assert_color(row_background_color)
 
         # Create frame row
-        row = Frame(1, 1, ORIENTATION_HORIZONTAL,
-                    frame_id=self._id + '+cell-row-' + uuid4(short=True))
+        row = Frame(1, 1, ORIENTATION_HORIZONTAL, frame_id=self._id + '+cell-row-' + uuid4(short=True))
         row._accepts_scrollarea = False
         row._accepts_title = False
         row._menu_can_be_none_pack = True
@@ -356,7 +355,6 @@ class Table(Frame):
 
                 # Check if Frame not recursive
                 if isinstance(c, Frame):
-                    print(self, c.get_widgets())
                     assert self not in c.get_widgets(unpack_subframes_include_frame=True), \
                         f'{self.get_class_id()} cannot be packed within {c.get_class_id()},' \
                         f' recursive packing is not allowed (Table is within Frame' \
@@ -365,13 +363,14 @@ class Table(Frame):
                 cell = c
                 if c._accept_events:
                     cell_widget_type = True
-                    warn(
-                        f'{self.get_class_id()} does not accept events in current'
-                        f' pygame-menu v{ver}; thus appended cell row widget '
-                        f'{c.get_class_id()} (pos {j}) would not work properly, '
-                        f'as it will ignore all inputs. Also, widgets within Tables'
-                        f' cannot be selected. Consider Tables as visual-only'
-                    )
+                    if self._verbose:
+                        warn(
+                            f'{self.get_class_id()} does not accept events in current'
+                            f' pygame-menu v{ver}; thus appended cell row widget '
+                            f'{c.get_class_id()} (pos {j}) would not work properly, '
+                            f'as it will ignore all inputs. Also, widgets within Tables'
+                            f' cannot be selected. Consider Tables as visual-only'
+                        )
                 # self._append_menu_update_frame(self)
 
             # Configure cell
